package websocket_fasthttp

import (
	"time"

	"github.com/valyala/fasthttp"
)

type SocketHandler interface {
	// Init invoked when server is stated
	// If you override ths method, must call
	Init() error
	// Handshake do handshake client and server
	// id is identity of client socket. if id is "", disallow connection
	Handshake(ctx *fasthttp.RequestCtx) (id string, extensionsHeader *fasthttp.ResponseHeader)
	// OnConnect invoked when client is connected
	// If you override ths method, must call
	OnConnect(soc *Socket)
	Handle(soc *Socket, stopChan <-chan struct{}, doneChan chan<- struct{})
	// OnDisconnect invoked when client is disconnected
	// If you override ths method, must call
	OnDisconnect(soc *Socket)
	// Destroy invoked when server is stopped
	// If you override ths method, must call
	Destroy()

	GetSocket(id string) *Socket
	GetSockets() map[string]*Socket

	GetMaxMessageSize() int64
	GetWriteTimeout() time.Duration
	GetReadTimeout() time.Duration
	GetPongTimeout() time.Duration
	GetPingTimeout() time.Duration
	GetPingPeriod() time.Duration

	// Validate is check handler value
	// If you override ths method, must call
	Validate()
}
